@@ -17,7 +17,8 @@ def download_urls(biosample: Dict) -> List:
     """Return list of download url from given biosample files.
         biosample: Dict, the response of a biosample request.
     """
-
     return [
-        f["cloud_metadata"]["url"] for f in normalize_sample(biosample)["files"]
+        f["cloud_metadata"]["url"]
+        for f in normalize_sample(biosample)["files"]
+        if "cloud_metadata" in f
     ]
